<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Кликни на иконицу у касети 
или притисни поново пречицу да зауставиш снимање</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Немојте окретати екран током снимања</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Усликавање</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Снимање</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Усликавање</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Снимак екрана</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Није сачувано. Молимо сачувајте у личном директоријуму.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Прикажи</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Усликавање завршено</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>изабери-површину</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сачувано у %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Занемари</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Остава</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Чување датототеке снимка, сачекајте...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Ефекти прозора су искључени у току процеса, снимање је морало бити заустављено</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Усликавање</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Неуспешно усликавање.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Слика клизањa</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Опозови</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Пусти</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Снимање завршено</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сачувано у %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Снимање</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Снимач Екрана ће се покренути за %1 сек.</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Потражи помоћ.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Неуспешно прављење непрекидне слике екрана.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Достигнуто је дно области клизања</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Достигнута је максимална дужина</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>подесите поље снимања</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Окрећите точкић миша или кликните да направите слику клизања</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Смањите брзину клизања</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Неправилна површина, кликните да </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Овде унеси текст</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Покрени/Усликавање</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Изађи/Сачувај</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Подешавање величине</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Брзо покретање</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Усликавање прозора</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Одложи усликавање</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Целовито усликавање</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Павоугаоник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Елипса</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линија</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Оловка</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Опозови</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Повећај висину горе</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Повећај висину доле</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Повећај ширину лево</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Повећај ширину десно</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Смањи висину горе</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Смањи висину доле</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Смањи ширину лево</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Смањи ширину десно</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Куцање</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Мрежна камера</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Почни снимање</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опције</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Почни/Снимање</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Миш</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Алати</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Издвоји текст</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Слика клизањa</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start OCR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелица</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Усликавање</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Кликни или превуци да
обележиш површину снимања</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Усликавање</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Микрофон</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation>Опције</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Прикажи показивач</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save to</source>
        <translation>Сачувај у</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Радна површина</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text (T)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Record</source>
        <translation>Снимање</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Остава</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Слике</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Фасцикла</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shadow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Издвоји текст</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> подесите површину снимања у оквиру %1*%2 да добијете бољи видео ефекат</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Снимање екрана тренутно није подржано</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Нови снимци</translation>
    </message>
</context>
</TS>